
-- Versatile Ada Genetic Algorithm Software system software component.
-- Max Edwards, Department of Computer Science, University of York, UK.
-- Email: me-b@minster.york.ac.uk
-- 
-- Copyright notice: This software is (C) Max Edwards 1995.  It may be
-- freely used and distributed provided that this message is not altered,
-- except that its use in military applications is not permitted.
-- Package name: DEJONG_PACK
-- Description: implementation of DeJong's test functions for optimization

with TEXT_IO, GENETIC, FIXED_POINT_CODING;
use TEXT_IO, GENETIC;

generic
  PARAM_BITS : INTEGER;
package DEJONG_PACK is
  use INT_IO, FLO_IO;
  PARAM_MAX : constant INTEGER := 2 ** PARAM_BITS - 1;
  MINX1 : constant FLOAT := -5.12;
  MAXX1 : constant FLOAT := 5.12;
  PARAMS1 : constant INTEGER := 3;
  MAXVAL1 : constant FLOAT := FLOAT(PARAMS1) * MAXX1 * MAXX1;
  MINX2 : constant FLOAT := -2.048;
  MAXX2 : constant FLOAT := 2.048;
  PARAMS2 : constant INTEGER := 2;
  MAXVAL2 : constant FLOAT := 3906.0;
  MINX3 : constant FLOAT := -5.12;
  MAXX3 : constant FLOAT := 5.12;
  PARAMS3 : constant INTEGER := 5;
  MAXVAL3 : constant FLOAT := FLOAT(PARAMS3) * 5.0;

  package CODING1 is new FIXED_POINT_CODING(PARAM_BITS, PARAMS1, MINX1, MAXX1)
    ;

  package CODING2 is new FIXED_POINT_CODING(PARAM_BITS, PARAMS2, MINX2, MAXX2)
    ;

  package CODING3 is new FIXED_POINT_CODING(PARAM_BITS, PARAMS3, MINX3, MAXX3)
    ;

  package CHROM1 renames CODING1.FPC_CHROM;

  package CHROM2 renames CODING2.FPC_CHROM;

  package CHROM3 renames CODING3.FPC_CHROM;

  procedure FITNESS1(CHROM : in out CHROM1.CHROMOSOME; FIT : out FITNESS_VALUE
    );

  procedure FITNESS2(CHROM : in out CHROM2.CHROMOSOME; FIT : out FITNESS_VALUE
    );

  procedure FITNESS3(CHROM : in out CHROM3.CHROMOSOME; FIT : out FITNESS_VALUE
    );

end DEJONG_PACK;

