
-- Versatile Ada Genetic Algorithm Software system software component.
-- Max Edwards, Department of Computer Science, University of York, UK.
-- Email: me-b@minster.york.ac.uk
-- 
-- Copyright notice: This software is (C) Max Edwards 1995.  It may be
-- freely used and distributed provided that this message is not altered,
-- except that its use in military applications is not permitted.
-- Package name: FIXED_POINT_CODING
-- Description: a multi-parameter fixed-point coding; provides a chromosome
-- package (FPC_CHROM), a PARAMETER_ARRAY type, and DECODE/ENCODE routines for
-- converting between them.

with STANDARD_CHROMOSOME, TEXT_IO, GENETIC;
use TEXT_IO;

generic
  PARAMETER_BITS : INTEGER;
  NUM_PARAMETERS : INTEGER;
  MIN_VALUE, MAX_VALUE : FLOAT;
package FIXED_POINT_CODING is
  use GENETIC.INT_IO, GENETIC.FLO_IO;
  SCALE : constant FLOAT :=
    (MAX_VALUE - MIN_VALUE) / FLOAT(2 ** PARAMETER_BITS - 1);
  type PARAMETER_ARRAY is array(1 .. NUM_PARAMETERS) of FLOAT;

  package FPC_CHROM is new STANDARD_CHROMOSOME(
    2, PARAMETER_BITS * NUM_PARAMETERS);

  function DECODE(CHROM : FPC_CHROM.CHROMOSOME) return PARAMETER_ARRAY;

  function ENCODE(PARAMS : PARAMETER_ARRAY) return FPC_CHROM.CHROMOSOME;

end FIXED_POINT_CODING;

