
-- Versatile Ada Genetic Algorithm Software system software component.
-- Max Edwards, Department of Computer Science, University of York, UK.
-- Email: me-b@minster.york.ac.uk
-- 
-- Copyright notice: This software is (C) Max Edwards 1995.  It may be
-- freely used and distributed provided that this message is not altered,
-- except that its use in military applications is not permitted.
-- Package name: GRAPHICS
-- Description : Provides basic graphics capabilities, encapsulating machine
-- dependencies.

with TEXT_IO;
use TEXT_IO;

package GRAPHICS is

-- Error handling:

  ILLEGAL_COORDINATE : exception;

  -- Bitmap declarations:

  subtype COLOUR is INTEGER range 0 .. 1;
  subtype POSITIVE_INTEGER is INTEGER range 1 .. INTEGER'LAST;
  type BITMAP is array(INTEGER range <>, INTEGER range <>) of COLOUR;

  -- Line-style declarations:

  type LINE_STYLE is array(INTEGER range <>) of BOOLEAN;
  SOLID : constant LINE_STYLE(1 .. 2) := (TRUE, TRUE);
  DOTTED : constant LINE_STYLE(1 .. 2) := (TRUE, FALSE);
  DASHED : constant LINE_STYLE(1 .. 3) := (TRUE, TRUE, FALSE);
  SPARSE : constant LINE_STYLE(1 .. 3) := (TRUE, FALSE, FALSE);

  -- Output filename declarations:

  FILENAME_LENGTH : constant := 9;
  OUTFILE : STRING(1 .. FILENAME_LENGTH) := "out0000.b";
  LAST_DIGIT : constant := 7;

  -- Graphical procedures:

  procedure CLEAR(BM : in out BITMAP; COL : in COLOUR := 0);

  procedure DRAW(BM : in out BITMAP; X1, Y1, X2, Y2 : POSITIVE_INTEGER;
                 COL : in COLOUR := 1; LSTYLE : in LINE_STYLE := SOLID);

  procedure NEXT_FILENAME;

  -- Device-dependent DISPLAY procedure(s):

  procedure YORK_DISPLAY(BM : in BITMAP);

  procedure ASCII_DISPLAY(BM : in BITMAP);

  -- Default DISPLAY procedure

  procedure DISPLAY(BM : in BITMAP) renames YORK_DISPLAY;

  -- Displays large bitmap as several XSIZE x YSIZE smaller ones, in the order
  -- bitmap1 bitmap2 bitmap3
  -- bitmap4 bitmap5 bitmap6 etc.:

  procedure SPLIT_DISPLAY(MAINBM : in BITMAP; XSIZE, YSIZE : in INTEGER);

end GRAPHICS;

