
-- Versatile Ada Genetic Algorithm Software system software component.
-- Max Edwards, Department of Computer Science, University of York, UK.
-- Email: me-b@minster.york.ac.uk
-- 
-- Copyright notice: This software is (C) Max Edwards 1995.  It may be
-- freely used and distributed provided that this message is not altered,
-- except that its use in military applications is not permitted.
-- Package: BASIC_MATHS
-- Provides an easier way to access the most commonly needed maths-functions.

with MATHS_LIBRARY, MATHS_CONSTANTS;

package BASIC_MATHS is
  PI : constant := MATHS_CONSTANTS.PI;
  subtype FRACTION is MATHS_LIBRARY.NUMERIC_SUBTYPES.FRACTION;
  subtype POSITIVE_FLOAT is MATHS_LIBRARY.NUMERIC_SUBTYPES.POSITIVE_FLOAT;

  function SIN(X : FLOAT) return FRACTION renames MATHS_LIBRARY.
    CIRCULAR_FUNCTIONS.SIN;

  function COS(X : FLOAT) return FRACTION renames MATHS_LIBRARY.
    CIRCULAR_FUNCTIONS.COS;

  function TAN(X : FLOAT) return FRACTION renames MATHS_LIBRARY.
    CIRCULAR_FUNCTIONS.TAN;

  function SQRT(X : FLOAT) return POSITIVE_FLOAT renames MATHS_LIBRARY.ROOTS.
    SQRT;

  function CBRT(X : FLOAT) return FLOAT renames MATHS_LIBRARY.ROOTS.CBRT;

end BASIC_MATHS;

