
-- Versatile Ada Genetic Algorithm Software system software component.
-- Max Edwards, Department of Computer Science, University of York, UK.
-- Email: me-b@minster.york.ac.uk
-- 
-- Copyright notice: This software is (C) Max Edwards 1995.  It may be
-- freely used and distributed provided that this message is not altered,
-- except that its use in military applications is not permitted.
-- Package name: REPORT
-- Description: provides a basic user-interface for genetic algorithm runs,
-- allowing runtime parameters to be altered, and fitness statistics to be
-- displayed.

with GENETIC, TEXT_IO, GRAPHICS;
use GENETIC, TEXT_IO, GRAPHICS;

package REPORT is
  use INT_IO, FLO_IO;

  -- Constants for fitness-history plotting mode:

  PLOT_MIN : constant INTEGER := 1;
  PLOT_MAX : constant INTEGER := 2;
  PLOT_AVG : constant INTEGER := 4;
  PLOT_BEF : constant INTEGER := 8;
  PLOT_ONLP : constant INTEGER := 16;
  PLOT_OFFLP : constant INTEGER := 32;

  procedure GET_PARAMETERS(PARAMS : in out RUN_PARAMETERS);

  procedure REPORT_PARAMETERS(PARAMS : in RUN_PARAMETERS);

  procedure SHORT_REPORT_HEADER;

  procedure SHORT_REPORT(STATS : in STATISTICS);

  procedure AUTO_REPORT(STATS : STATISTICS; REPORT_RATE : INTEGER);

  procedure DISPLAY_FITNESS_HISTORY(
    STATS : in STATISTICS; YRES : in INTEGER; MODE : in INTEGER := 7);

end REPORT;

