
-- Versatile Ada Genetic Algorithm Software system software component.
-- Max Edwards, Department of Computer Science, University of York, UK.
-- Email: me-b@minster.york.ac.uk
-- 
-- Copyright notice: This software is (C) Max Edwards 1995.  It may be
-- freely used and distributed provided that this message is not altered,
-- except that its use in military applications is not permitted.
-- Package name: SCALING
-- Description: contains some scaling routines, ready for use with the
-- GENETIC_ALGORITHM package.  You can provide your own if you wish.
-- All scaling routines must conform to the spec. of the ones below.  Each
-- can assume that STATS.RAW_FITNESSES and STATS.SCALED_FITNESSES both
-- contain raw fitnesses upon entry; the scaling routine must ensure that
-- it only alters STATS.SCALED_FITNESSES, and update STATS.SUM_SCALED_FITNESS
-- accordingly.  No other changes to the STATS record should be made.

with GENETIC, TEXT_IO;
use GENETIC, TEXT_IO;

package SCALING is
  use INT_IO, FLO_IO;

  procedure NO_SCALING(STATS : in out STATISTICS);

  -- Has no effect on the statistics; needed because generic GA requires a
  -- scaling routine even if you don't want scaling.

  procedure SIMPLE_LINEAR_SCALING(STATS : in out STATISTICS);

  -- Perform simple linear scaling in the statistics record given.
  -- loosely based on algorithm due to Goldberg "GA's in Machine Learning..." P79

  procedure TWO_SECTION_SCALING(STATS : in out STATISTICS);

  -- A variation on simple-linear scaling that uses two scaling gradients, one
  -- for min..avg and the other for avg..max; this ensures that max always scales
  -- to fmult * avg, avg always scales to avg, and min always scales to zero.

  procedure RANK_SCALING(STATS : in out STATISTICS);

  -- Assigns each individual a fitness corresponding to its rank in a sorted
  -- fitness list, i.e. min -> 0, max -> pop_size-1 (assuming no duplicate
  -- fitnesses)

end SCALING;

