
-- Versatile Ada Genetic Algorithm Software system software component.
-- Max Edwards, Department of Computer Science, University of York, UK.
-- Email: me-b@minster.york.ac.uk
-- 
-- Copyright notice: This software is (C) Max Edwards 1995.  It may be
-- freely used and distributed provided that this message is not altered,
-- except that its use in military applications is not permitted.
-- Package name: SELECTION
-- Description: provides some common methods of selection, ready to "plug in"
-- to the GENETIC_ALGORITHM package.

with GENETIC, TEXT_IO, RANDOM_NUMBERS;
use GENETIC, TEXT_IO, RANDOM_NUMBERS;

package SELECTION is
  use INT_IO, FLO_IO;

  function ROULETTE_SELECT(STATS : STATISTICS) return PARENT_LIST;

  -- "Roulette Wheel" selection of string pairs from old group
  -- (chance of selection = fitness/sum_fitness)
  -- Returns a PARENT_LIST which is a list of numbers, where successive
  -- pairs indicate the indexes of the parents to be used for each mating

  function PICK_SELECT(STATS : STATISTICS) return PARENT_LIST;

  -- Chooses an individual at random, and includes it in the parent_list with a
  -- probability proportional to its fitness.  Repeats this process until parent
  -- list is full.

  function TOURNAMENT_SELECT(STATS : STATISTICS) return PARENT_LIST;

  function RANDOM_SELECT(STATS : STATISTICS) return PARENT_LIST;

end SELECTION;

