
-- Versatile Ada Genetic Algorithm Software system software component.
-- Max Edwards, Department of Computer Science, University of York, UK.
-- Email: me-b@minster.york.ac.uk
-- 
-- Copyright notice: This software is (C) Max Edwards 1995.  It may be
-- freely used and distributed provided that this message is not altered,
-- except that its use in military applications is not permitted.
-- Package name: STANDARD_CHROMOSOME
-- Description : a generic package providing standard chromosome-string data
-- type, and associated manipulation procedures, to allow simple genetic
-- algorithms to be easily created with the GENETIC.ALGORITHM package

with RANDOM_NUMBERS, GENETIC, TEXT_IO;
use RANDOM_NUMBERS, GENETIC, TEXT_IO;

generic
  ALLELES : INTEGER;
  CHROM_LENGTH : INTEGER;
package STANDARD_CHROMOSOME is
  use INT_IO, FLO_IO;
  subtype GENE is INTEGER range 0 .. ALLELES - 1;
  type CHROMOSOME is array(1 .. CHROM_LENGTH) of GENE;

  -- Useful routines for chromosome manipulation (RANDOM_CHROMOSOME,
  -- CROSSOVER and MUTATE are mandatory):

  function RANDOM_CHROMOSOME return CHROMOSOME;

  -- Return a random chromosome string

  procedure SIMPLE_CROSSOVER(
    PARENT1, PARENT2 : in CHROMOSOME; CHILD1, CHILD2 : out CHROMOSOME);

  -- Standard single-point crossover between two strings

  procedure TWO_POINT_CROSSOVER(
    PARENT1, PARENT2 : in CHROMOSOME; CHILD1, CHILD2 : out CHROMOSOME);

  -- each point takes its value from either parent, with a 50/50 probability

  procedure UNIFORM_CROSSOVER(
    PARENT1, PARENT2 : in CHROMOSOME; CHILD1, CHILD2 : out CHROMOSOME);

  procedure CHANGE_CROSSOVER(
    PARENT1, PARENT2 : in CHROMOSOME; CHILD1, CHILD2 : out CHROMOSOME);

  procedure SIMPLE_MUTATE(
    CHROM : in out CHROMOSOME; MRATE : in PROBABILITY; MTOT : in out INTEGER);

  -- Simple mutation

  procedure CREEP_MUTATE(
    CHROM : in out CHROMOSOME; MRATE : in PROBABILITY; MTOT : in out INTEGER);

  procedure SCRAMBLE_MUTATE(
    CHROM : in out CHROMOSOME; MRATE : in PROBABILITY; MTOT : in out INTEGER);

  procedure SCRAMBLE_SUBSET_MUTATE(
    CHROM : in out CHROMOSOME; MRATE : in PROBABILITY; MTOT : in out INTEGER);

  function NUMERIC_DECODE(CHROM : in CHROMOSOME; START_POS, END_POS : INTEGER)
    return INTEGER;

end STANDARD_CHROMOSOME;

