
-- Versatile Ada Genetic Algorithm Software system software component.
-- Max Edwards, Department of Computer Science, University of York, UK.
-- Email: me-b@minster.york.ac.uk
-- 
-- Copyright notice: This software is (C) Max Edwards 1995.  It may be
-- freely used and distributed provided that this message is not altered,
-- except that its use in military applications is not permitted.
-- Package name: TSP_PACK
-- Description: a "problem package", containing a chromosome package, a
-- fitness function and other useful routines, to allow quick and easy
-- construction of a TSP genetic algorithm.

with TEXT_IO, GENETIC, PERMUTATION_CHROMOSOME, RANDOM_NUMBERS, BASIC_MATHS,
  GRAPHICS;
use TEXT_IO, GENETIC, RANDOM_NUMBERS, BASIC_MATHS, GRAPHICS;

generic
  CITIES : INTEGER;
package TSP_PACK is
  use INT_IO, FLO_IO;

  -- Expected Minimal Tour according to D.Stein's "Scheduling
  -- Dial-a-Ride Transportation Systems: An Asymptotic Approach",
  -- Harvard PhD Disseration, 1977:

  EXPECTED_MINIMAL_TOUR : constant FLOAT := 0.765 * SQRT(FLOAT(CITIES));

  -- type definitons:

  type DIST_MATRIX is array(1 .. CITIES, 1 .. CITIES) of FLOAT;
  type COORD is
    record
      X, Y : FLOAT := 0.0;
    end record;
  type MAP is array(1 .. CITIES) of COORD;
  THE_MAP : MAP;
  DISTANCES : DIST_MATRIX;
  XSIZE : constant INTEGER := 128;
  YSIZE : constant INTEGER := 128;
  SCREEN : BITMAP(1 .. XSIZE, 1 .. YSIZE);

  package TSP_CHROM is new PERMUTATION_CHROMOSOME(CITIES);

  procedure INIT_DIST_MATRIX;

  procedure DISPLAY_PATH(CHROM : TSP_CHROM.CHROMOSOME);

  procedure FITNESS(
    CHROM : in out TSP_CHROM.CHROMOSOME; FIT : out FITNESS_VALUE);

end TSP_PACK;

