
-- Versatile Ada Genetic Algorithm Software system software component.
-- Max Edwards, Department of Computer Science, University of York, UK.
-- Email: me-b@minster.york.ac.uk
-- 
-- Copyright notice: This software is (C) Max Edwards 1995.  It may be
-- freely used and distributed provided that this message is not altered,
-- except that its use in military applications is not permitted.
-- Package: TTBL_PACK
-- Description: Problem package for an example timetabling problem

with GENETIC, TEXT_IO, RANDOM_NUMBERS, STANDARD_CHROMOSOME;
use GENETIC, TEXT_IO, RANDOM_NUMBERS;

generic

  -- Problem-specific declarations:

  NUM_COURSES : INTEGER := 20;
  NUM_LOCATIONS : INTEGER := 4;
  NUM_TIMESLOTS : INTEGER := 10;
  PBITS : INTEGER := 4;

  -- Make sure PBITS is minimum value that satisfies
  -- 2**PBITS >= max(num_locations, num_timeslots)

  NUM_STUDENTS : INTEGER := 25;
  MAX_CPS : INTEGER := 7;
  MIN_CPS : INTEGER := 3;
  NUM_LECTURERS : INTEGER := 8;
package TTBL_PACK is
  use FLO_IO, INT_IO;
  type ENROLLMENTS_TABLE is array(1 .. NUM_STUDENTS, 1 .. NUM_COURSES) of
    BOOLEAN;
  ENROLLED : ENROLLMENTS_TABLE;
  type LECTURER_LIST is array(1 .. NUM_COURSES) of INTEGER;
  LECTURER : LECTURER_LIST;
  type TIME_TABLE_ENTRY is
    record
      LOCATION : INTEGER range 1 .. NUM_LOCATIONS;
      TIMESLOT : INTEGER range 1 .. NUM_TIMESLOTS;
    end record;
  type TIME_TABLE is array(1 .. NUM_COURSES) of TIME_TABLE_ENTRY;

  procedure GET_COURSE_INFO;

  procedure SHOW_COURSE_INFO;

  function TTBL_FITNESS(TTBL : TIME_TABLE) return FITNESS_VALUE;

  package TTBL_CHROM is new STANDARD_CHROMOSOME(2, 2 * PBITS * NUM_COURSES);

  procedure FITNESS(
    CHROM : in out TTBL_CHROM.CHROMOSOME; FIT : out FITNESS_VALUE);

end TTBL_PACK;

